/* $Workfile: OtxPots.h $   $Revision: 24 $    $Modtime: 8/06/04 3:00p $  */
#ifndef OTX_POTS_H
#define OTX_POTS_H
/*******************************************************************************

  @doc PublicHwApi OtxPots

  Copyright (C) 1998 - 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxPots | This file contains prototypes for the Analog Phone Functions

  @contents2
  OtxPots.h |

  @index func | OtxPots

  @contents2
  OTX POTS Line Interface Device Functions - OtxPotsXXX() | The user functions available for
  the Analog Phone Line Interface Decivces following;

  @head3 OtxPotsXXX() Function Reference |

  @index func | OtxPots

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions
#include "OtxDef.h"     // OTX specific definitions

#include "OtxPotsD.h"    // OTX POTS type definitions

#ifdef __cplusplus
extern "C" {
#endif


/*******************************************************************************

  @func
    Make the POTS line device to go off-hook

  @comm
    This function does not wait for a dial tone, to wait for a dial tone, 
    an Audio Receiver must be associated with the Line Device. This is done 
    by installing the Audio module and connecting PotsLine timeslots to 
    Audio Receivers in the Audio Module by means of the Tss module.

    No operation if already off-hook.

  @ex |

    hCurrentPotsLine = g_hPhysDevs.hLi[nCurrentPotsLine];

    // set active POTS Line Off-Hook
    result = OtxPotsOffHook(hCurrentPotsLine); 

  @xref
    <f OtxPotsOnHook>
    <nl><f OtxPotsHookFlash>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxPotsOffHook(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    Make the POTS line device go on-hook

  @comm
    No operation if already off-hook.

  @ex |
  
    hCurrentPotsLine = g_hPhysDevs.hLi[nCurrentPotsLine];
    
    // set active POTS Line On-Hook
    result = OtxPotsOnHook(hCurrentPotsLine); 

  @xref
    <f OtxPotsOffHook>
    <nl><f OtxPotsHookFlash>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxPotsOnHook(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    An atomic on-hook off-hook operation

  @comm
    A non-operation if the device is not off-hook

  @ex |
    
    hCurrentPotsLine = g_hPhysDevs.hLi[nCurrentPotsLine];

    // flash Hook on current POTS line
    result = OtxPotsHookFlash(
                hCurrentPotsLine, 
                200, 
                OTX_TASK_SYNC, 
                5000L); 

  @xref
    <f OtxPotsOffHook>
    <nl><f OtxPotsOnHook>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxPotsHookFlash(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OTX_TIME         nDurationMs,        // @parm Time to stay on-hook.
  IN OTX_TASK_REF     nTaskRef,           // @parm Callers reference, see also <t OTX_TASK_REF>.
  IN OTX_TIME         nWaitMaxMs          // @parm Maximum time for operation to complete, see also <t OTX_TIME>.
);


/*******************************************************************************

  @func
    Dial a phone number in the form of legacy pulse groups.

  @comm
    A pulse group is realized as group of pulses. Example, in Sweden a
    '0' is one pulse, and '1' are two pulses.

    A pulse is a disconnection of the line, and it is therefore a
    prerequisite that the line is off-hook prior to calling this
    function.

  @ex |
    
    char *g_sqNumber0 = "102";

    hCurrentPotsLine = g_hPhysDevs.hLi[nCurrentPotsLine];
    
    // pulse dial "102"
    result = OtxPotsPulseDial(
                hCurrentPotsLine, 
                40, 
                60, 
                500, 
                (OTX_UINT8 *) g_sqNumber0, 
                strlen(g_sqNumber0), 
                DEMO_TASK_REF, 
                OTX_TIME_INFINITY); 

  @xref
    <f OtxToneDtmfDial>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxPotsPulseDial(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OTX_TIME         nDisconnectMs,      // @parm Time to keep line on-hook for each pulse
  IN OTX_TIME         nConnectMs,         // @parm Time to keep line off-hook for each pulse
  IN OTX_TIME         nInterPulseGroupMs, // @parm Time to keep line off-hook between each pulse group (i.e. digit)
  IN OTX_UINT8        *sqPulseGroups,     // @parm Sequence (i.e. array) of digits constituting one pulse group each
  IN OTX_UINT32       coPulseGroups,      // @parm Count of digits (i.e. pulse groups)
  IN OTX_TASK_REF     nTaskRef,           // @parm Callers reference, see also <t OTX_TASK_REF>.
  IN OTX_TIME         nWaitMaxMs          // @parm Maximum time for operation to complete, see also <t OTX_TIME>.
);


/*******************************************************************************

  @func
    Set the Line Interface Mode.

  @comm
    This function is mainly used for testing/debugging. Not needed in
    normal applications.

  @ex |
    // set the operation mode of the Active POTS LI Device 
    OtxPotsLiModeE eLiMode;
    
    hCurrentPotsLine = g_hPhysDevs.hLi[nCurrentPotsLine];
    eLiMode = OTX_POTS_MODE_RINGING;

    result = OtxPotsSetLiMode(
                hCurrentPotsLine, 
                eLiMode);

  @xref
    <f OtxPotsGetLiMode>
    <nl><t OtxPotsLiModeE>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxPotsSetLiMode(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OtxPotsLiModeE   eLiMode             // @parm Line Interface Device mode
);


/*******************************************************************************

  @func
    Returns the Line Interface Mode of the device.

  @ex |
    // read the operation mode of the Active LI Device ...
    OtxPotsLiModeE eLiMode;

    hCurrentPotsLine = g_hPhysDevs.hLi[nCurrentPotsLine];

    result = OtxPotsGetLiMode(
                hCurrentPotsLine, 
                &eLiMode);
    
  @xref
    <f OtxPotsSetLiMode>
    <nl><t OtxPotsLiModeE>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxPotsGetLiMode(
  IN  OTX_HANDLE      hDevice,            // @parm A handle to a POTS line device.
  OUT OtxPotsLiModeE  *peLiMode           // @parm Line Interface Device mode
);



#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998 - 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif    // OTX_POTS_H

